@@ -15,6 +15,9 @@ class Text(Box):
             return self.value.to_markdown()
         return self.value
 
+    def __bool__(self) -> bool:
+        return bool(self.value)
+
 
 class LabeledText(Box):
     def __init__(self, name: str, value: Union[Box, str]):
@@ -25,7 +28,12 @@ class LabeledText(Box):
         else:
             self._value = value
 
+        if not self._name:
+            raise ValueError("Name must not be empty.")
+
     def to_markdown(self) -> str:
+        if not self._value:
+            return self._name.to_markdown()
         return "{} {}".format(self._name.to_markdown(), self._value.to_markdown())
 
     @property
@@ -34,7 +42,10 @@ class LabeledText(Box):
 
     @name.setter
     def name(self, name: Union[str, Box]) -> None:
-        self._name = BoldText(name)
+        name = BoldText(name)
+        if not name:
+            raise ValueError("Name must not be empty.")
+        self._name = name
 
     @property
     def value(self) -> Box:
@@ -44,6 +55,9 @@ class LabeledText(Box):
     def value(self, value: Union[str, Box]) -> None:
         self._value = Text(value)
 
+    def __bool__(self) -> bool:
+        return bool(self.value)
+
 
 class LinkedText(Box):
     def __init__(self, name: str, link: str):
@@ -62,6 +76,9 @@ class LinkedText(Box):
     def name(self, value: Union[str, Box]) -> None:
         self._name = Text(value)
 
+    def __bool__(self) -> bool:
+        return bool(self.name)
+
 
 class BoldText(Box):
     def __init__(self, value: Union[str, Text, LinkedText]):
@@ -79,6 +96,9 @@ class BoldText(Box):
     def value(self, value: Union[str, Box]) -> None:
         self._value = Text(value)
 
+    def __bool__(self) -> bool:
+        return bool(self.value)
+
 
 class InlineText(Box):
     def __init__(self, value: Union[str, Box]):
@@ -96,6 +116,9 @@ class InlineText(Box):
     def value(self, value: Union[str, Box]) -> None:
         self._value = Text(value)
 
+    def __bool__(self) -> bool:
+        return bool(self.value)
+
 
 class BlockText(Box):
     def __init__(self, value: Union[str, Box]):
@@ -113,6 +136,9 @@ class BlockText(Box):
     def value(self, value: Union[str, Box]) -> None:
         self._value = Text(value)
 
+    def __bool__(self) -> bool:
+        return bool(self.value)
+
 
 class HighlightableLinks(Box):
     def __init__(self, links: List[LinkedText], highlighted: int, delimiter: str = ", "):
@@ -137,6 +163,9 @@ class HighlightableLinks(Box):
             raise Exception("Selected is out of bounds")
         self.highlighted = self.links[highlighted]
 
+    def __bool__(self) -> bool:
+        return any(self.links)
+
 
 class CustomEmoji(Box):
     def __init__(self, emoji: Emoji):
@@ -145,3 +174,6 @@ class CustomEmoji(Box):
 
     def to_markdown(self) -> str:
         return "<{}:{}:{}>".format("a" if self.emoji.animated else "", self.emoji.name, self.emoji.id)
+
+    def __bool__(self) -> bool:
+        return True
